/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.service;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;

import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

@Controller
public class AdminController {
    public static final String ADMIN_KEY = "isAdmin";

    private static final Logger log = LogManager.getLogger(AdminController.class);
    private static final String LTR_DEST_PATH = "/ltr";
    private static final String BTR_DEST_PATH = "/btr";

    @Autowired
    private ServletContext servletContext;

    @RequestMapping(value = "/ltrAdmin")
    public void adminEndpointLTR(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        forwardAdminCall(request, response, LTR_DEST_PATH);
    }

    @RequestMapping(value = "/btrAdmin")
    public void adminEndpointBTR(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        forwardAdminCall(request, response, BTR_DEST_PATH);
    }

    private void forwardAdminCall(HttpServletRequest request, HttpServletResponse response, String path) throws ServletException, IOException {
        log.debug("Admin endpoint invoked from " + request.getRemoteAddr() + ", delegating to " + path);

        request.setAttribute(ADMIN_KEY, true); // mark request as an admin request
        servletContext.getRequestDispatcher(path).forward(request, response);
    }
}
