/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.service;

import dk.sundhedsdatastyrelsen.livstestamente.service.integrations.minlog.MinLogClient;
import dk.sundhedsdatastyrelsen.livstestamente.service.integrations.minlog.MinLogException;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.context.annotation.Bean;

import javax.annotation.PostConstruct;
import java.time.Instant;

@SpringBootApplication
public class LivingWillApplication {

    private static final Logger log = LogManager.getLogger(LivingWillApplication.class);

    static Instant DEPLOY_TIME = Instant.now();

    private static final String MINLOG_CONFIG_FILE_NAME = "minlogclient.properties";

    @Bean
    public MinLogClient minLogClient() throws MinLogException {
        return new MinLogClient(
                "LTR-BTR-MinLogClientConfig",
                MINLOG_CONFIG_FILE_NAME);
    }

    @PostConstruct
    public void logSettings() {
        log.info("Info logging is enabled.");
        log.debug("Debug logging is enabled.");
        log.trace("Trace logging is enabled.");
    }
}
