/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.service;

import dk.sundhedsdatastyrelsen.livstestamente.service.util.WSDLHelper;
import org.apache.commons.io.IOUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.nio.charset.StandardCharsets;

@Controller
public class WSDLController {

    private static final Logger logger = LogManager.getLogger(WSDLController.class);

    @GetMapping(value = "/wsdl", produces = "text/html")
    @ResponseBody
    public ResponseEntity wsdl() throws IOException {
        logger.debug("WSDL overview request");

        InputStream in = getClass().getResourceAsStream("/static/wsdl_overview.html");
        Reader reader = new InputStreamReader(in, StandardCharsets.UTF_8);
        String text = IOUtils.toString(reader);
        return ResponseEntity.ok().body(text);
    }

    @GetMapping(value = "/wsdl/ltr/dgws", produces = "text/xml")
    @ResponseBody
    public ResponseEntity<String> ltrWsdlDGWS(HttpServletRequest request) throws IOException {
        logger.debug("WSDL dgws request");
        return outputString("/wsdl/ltr/livstestamente_dgws_service_2018_05_01.wsdl", request.getRequestURL().toString());
    }

    @GetMapping(value = "/wsdl/ltr/idws", produces = "text/xml")
    @ResponseBody
    public ResponseEntity<String> ltrWsdlIDWS(HttpServletRequest request) throws IOException {
        logger.debug("WSDL idws request");
        return outputString("/wsdl/ltr/livstestamente_idws_service_2018_05_01.wsdl", request.getRequestURL().toString());
    }

    @GetMapping(value = "/wsdl/btr/dgws", produces = "text/xml")
    @ResponseBody
    public ResponseEntity<String> btrWsdlDGWS(HttpServletRequest request) throws IOException {
        logger.debug("WSDL dgws request");
        return outputString("/wsdl/btr/behandlingstestamente_dgws_service_2018_05_01.wsdl", request.getRequestURL().toString());
    }

    @GetMapping(value = "/wsdl/btr/idws", produces = "text/xml")
    @ResponseBody
    public ResponseEntity<String> btrWsdlIDWS(HttpServletRequest request) throws IOException {
        logger.debug("WSDL idws request");
        return outputString("/wsdl/btr/behandlingstestamente_idws_service_2018_05_01.wsdl", request.getRequestURL().toString());
    }
    
    @GetMapping(value = "/wsdl/btrV2/dgws", produces = "text/xml")
    @ResponseBody
    public ResponseEntity<String> btrWsdlDGWSv2(HttpServletRequest request) throws IOException {
        logger.debug("WSDL dgws request v2");
        return outputString("/wsdl/btr/behandlingstestamente_dgws_service_2020_03_16.wsdl", request.getRequestURL().toString());
    }

    @GetMapping(value = "/wsdl/btrV2/idws", produces = "text/xml")
    @ResponseBody
    public ResponseEntity<String> btrWsdlIDWSv2(HttpServletRequest request) throws IOException {
        logger.debug("WSDL idws request v2");
        return outputString("/wsdl/btr/behandlingstestamente_idws_service_2020_03_16.wsdl", request.getRequestURL().toString());
    }

    @GetMapping(value = "/schema/**", produces = "text/xml")
    @ResponseBody
    public ResponseEntity<String> schemaFile(HttpServletRequest request) throws IOException {
        String servletPath = request.getServletPath();
        logger.debug("Schema request: " + servletPath);
        return outputString(servletPath, request.getRequestURL().toString());
    }

    private ResponseEntity<String> outputString(String resource, String requestURL) throws IOException {
        InputStream in = getClass().getResourceAsStream(resource);
        Reader reader = new InputStreamReader(in, StandardCharsets.UTF_8);
        String text = IOUtils.toString(reader);

        if (requestURL != null) {
            text = WSDLHelper.replaceSchemaLocations(text, requestURL);
        }

        return ResponseEntity.ok().body(text);
    }

}
