/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.service.conf;

import dk.cprsubscriber.dao.PersonSimplifiedDAO;
import dk.cprsubscriber.dao.impl.PersonSimplifiedDAOImpl;
import dk.sundhedsdatastyrelsen.livstestamente.service.util.Properties;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Profile;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;
import org.springframework.jdbc.datasource.lookup.JndiDataSourceLookup;
import org.springframework.transaction.PlatformTransactionManager;

import javax.sql.DataSource;

@Configuration
@Profile("production")
public class DAOConfig {

    private final Properties properties;

    @Autowired
    public DAOConfig(Properties properties) {
        this.properties = properties;
    }

    @Bean
    public DataSource livingWillDataSource() {
        JndiDataSourceLookup dataSourceLookup = new JndiDataSourceLookup();
        return dataSourceLookup.getDataSource(properties.getDataSourceLtrJNDIName());
    }

    @Bean
    public PlatformTransactionManager livingWillDataSourceTxManager(@Qualifier("livingWillDataSource")DataSource livingWillDataSource) {
        return new DataSourceTransactionManager(livingWillDataSource);
    }

    @Bean
    public DataSource treatmentWillDataSource() {
        JndiDataSourceLookup dataSourceLookup = new JndiDataSourceLookup();
        return dataSourceLookup.getDataSource(properties.getDataSourceBtrJNDIName());
    }

    @Bean
    public PlatformTransactionManager treatmentWillDataSourceTxManager(@Qualifier("treatmentWillDataSource") DataSource treatmentWillDataSource) {
        return new DataSourceTransactionManager(treatmentWillDataSource);
    }

    /**
     * We do not configure a TransactionManager for this datasource, as we do not need transactions for this.
     */
    @Bean
    public DataSource stamdataDataSource() {
        JndiDataSourceLookup dataSourceLookup = new JndiDataSourceLookup();
        return dataSourceLookup.getDataSource(properties.getDataSourceStamdataJNDIName());
    }

    @Bean
    public PersonSimplifiedDAO personSimplifiedDAO(@Qualifier("stamdataDataSource") DataSource stamdataDataSource) {
        return new PersonSimplifiedDAOImpl(stamdataDataSource);
    }
}
