/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.service.webservice;

import dk.sundhedsdatastyrelsen.livstestamente.service.util.FaultCode;
import dk.sundhedsdatastyrelsen.livstestamente.service.util.FaultUtil;
import dk.sundhedsdatastyrelsen.livstestamente.service.util.ServiceException;
import dk.sundhedsdatastyrelsen.livstestamente.service.webservice.exceptions.ParseException;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public abstract class AbstractWebService {

    private static final Logger logger = LogManager.getLogger(AbstractWebService.class);

    void commonExceptionHandler(Exception e, FaultCode validationErrorCode, FaultCode internalServerErrorCode) throws Exception {
        if (e instanceof IllegalArgumentException || e instanceof ParseException) {
            // Ok to reveal detailed information

            logger.info("Service call threw the following request validation exception: " + e.getMessage());

            FaultUtil.throwFault(validationErrorCode,
                    validationErrorCode.getCode() + ": " + validationErrorCode.getMessage()
                            + " Details: " + e.getMessage());

        } else if (e instanceof ServiceException) {
            // Ok to reveal detailed information (two error codes will be present)
            throw e;
        }

        // Not ok to reveal detailed information
        logger.error("Service call produced the an unrecognized exception with code", e);
        FaultUtil.throwFault(internalServerErrorCode,
                internalServerErrorCode.getCode() + ": " + internalServerErrorCode.getMessage());
    }

}
