/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.service.webservice;

import dk.sundhedsdatastyrelsen.behandlingstestamente._2018._05._01.*;
import dk.sundhedsdatastyrelsen.livstestamente._2018._05._01.*;
import dk.sundhedsdatastyrelsen.livstestamente.service.AdminController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.ws.server.endpoint.annotation.Endpoint;
import org.springframework.ws.server.endpoint.annotation.RequestPayload;
import org.springframework.ws.server.endpoint.annotation.ResponsePayload;
import org.springframework.ws.soap.server.endpoint.annotation.SoapAction;

import javax.servlet.http.HttpServletRequest;

@Endpoint
public class WebServiceDelegate {
    @Autowired
    private HttpServletRequest context;

    private final TreatmentWillWebService treatmentWillWebService;
    private final LivingWillWebService livingWillWebService;

    @Autowired
    public WebServiceDelegate(TreatmentWillWebService treatmentWillWebService, LivingWillWebService livingWillWebService) {
        this.treatmentWillWebService = treatmentWillWebService;
        this.livingWillWebService = livingWillWebService;
    }

    //Endpoint for TreatmentWill
    @SoapAction("http://sundhedsdatastyrelsen.dk/behandlingstestamente/2018/05/01#GetTreatmentWill")
    @ResponsePayload
    public GetTreatmentWillResponse getTreatmentWill(@RequestPayload GetTreatmentWillRequest request) throws Exception {
        return treatmentWillWebService.getTreatmentWill(request, isAdmin());
    }

    @SoapAction("http://sundhedsdatastyrelsen.dk/behandlingstestamente/2018/05/01#HasTreatmentWill")
    @ResponsePayload
    public HasTreatmentWillResponse hasTreatmentWill(@RequestPayload HasTreatmentWillRequest request) throws Exception {
        return treatmentWillWebService.hasTreatmentWill(request, isAdmin());
    }

    @SoapAction("http://sundhedsdatastyrelsen.dk/behandlingstestamente/2018/05/01#CreateTreatmentWill")
    @ResponsePayload
    public CreateTreatmentWillResponse createTreatmentWill(@RequestPayload CreateTreatmentWillRequest request) throws Exception {
        return treatmentWillWebService.createTreatmentWill(request, isAdmin());
    }

    @SoapAction("http://sundhedsdatastyrelsen.dk/behandlingstestamente/2018/05/01#UpdateTreatmentWill")
    @ResponsePayload
    public UpdateTreatmentWillResponse updateTreatmentWill(@RequestPayload UpdateTreatmentWillRequest request) throws Exception {
        return treatmentWillWebService.updateTreatmentWill(request, isAdmin());
    }

    @SoapAction("http://sundhedsdatastyrelsen.dk/behandlingstestamente/2018/05/01#DeleteTreatmentWill")
    @ResponsePayload
    public DeleteTreatmentWillResponse deleteTreatmentWill(@RequestPayload DeleteTreatmentWillRequest request) throws Exception {
        return treatmentWillWebService.deleteTreatmentWill(request, isAdmin());
    }

    //Endpoint for LivingWill
    @SoapAction("http://sundhedsdatastyrelsen.dk/livstestamente/2018/05/01#GetLivingWill")
    @ResponsePayload
    public GetLivingWillResponse getLivingWill(@RequestPayload GetLivingWillRequest request) throws Exception {
        return livingWillWebService.getLivingWill(request, isAdmin());
    }

    @SoapAction("http://sundhedsdatastyrelsen.dk/livstestamente/2018/05/01#HasLivingWill")
    @ResponsePayload
    public HasLivingWillResponse hasLivingWill(@RequestPayload HasLivingWillRequest request) throws Exception {
        return livingWillWebService.hasLivingWill(request, isAdmin());
    }

    @SoapAction("http://sundhedsdatastyrelsen.dk/livstestamente/2018/05/01#CreateLivingWill")
    @ResponsePayload
    public CreateLivingWillResponse createLivingWill(@RequestPayload CreateLivingWillRequest request) throws Exception {
        return livingWillWebService.createLivingWill(request, isAdmin());
    }

    @SoapAction("http://sundhedsdatastyrelsen.dk/livstestamente/2018/05/01#UpdateLivingWill")
    @ResponsePayload
    public UpdateLivingWillResponse updateLivingWill(@RequestPayload UpdateLivingWillRequest request) throws Exception {
        return livingWillWebService.updateLivingWill(request, isAdmin());
    }

    @SoapAction("http://sundhedsdatastyrelsen.dk/livstestamente/2018/05/01#DeleteLivingWill")
    @ResponsePayload
    public DeleteLivingWillResponse deleteLivingWill(@RequestPayload DeleteLivingWillRequest request) throws Exception {
        return livingWillWebService.deleteLivingWill(request, isAdmin());
    }

    private boolean isAdmin() {
        Boolean isAdmin = (Boolean) context.getAttribute(AdminController.ADMIN_KEY);
        return isAdmin != null ? isAdmin : false;
    }
}

