/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.service.webservice.proxydata;

import dk.sds.dgws_idws_proxy.security.ProxyConstants;
import dk.sds.dgws_idws_proxy.security.ProxyData;
import dk.sds.dgws_idws_proxy.util.ProxyUtil;
import dk.sundhedsdatastyrelsen.livstestamente.service.util.FaultCode;
import dk.sundhedsdatastyrelsen.livstestamente.service.util.FaultUtil;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.stereotype.Component;
import org.springframework.ws.transport.context.TransportContext;
import org.springframework.ws.transport.context.TransportContextHolder;
import org.springframework.ws.transport.http.HttpServletConnection;

import javax.servlet.http.HttpServletRequest;


@Component
public class ProxyDataProvider {
    private static final Logger logger = LogManager.getLogger(ProxyDataProvider.class);

    ProxyData getProxyData() {
        String proxyDataJson = getHttpHeaderValue(ProxyConstants.PROXY_DATA_HEADER_NAME);

        ProxyData proxyData = null;
        if (proxyDataJson != null) {
            logger.debug("ProxyData: " + proxyDataJson);
            try {
                proxyData = ProxyUtil.deserialize(proxyDataJson);
            } catch (Exception e) {
                // Ignore and return null;
                logger.error("Could not deserialize the header " + ProxyConstants.PROXY_DATA_HEADER_NAME + ". Data: " + proxyDataJson);
            }
        } else {
            logger.error("No ProxyData was received in the header: " + ProxyConstants.PROXY_DATA_HEADER_NAME);
        }

        if (proxyData == null) {
            FaultUtil.throwFault(FaultCode.AUTHORIZATION_ERROR_INVALID_HEADER);
        }

        return proxyData;
    }

    private String getHttpHeaderValue(final String headerName) {
        HttpServletRequest httpServletRequest = getHttpServletRequest();
        return (null != httpServletRequest) ? httpServletRequest.getHeader(headerName) : null;
    }

    private HttpServletRequest getHttpServletRequest() {
        TransportContext ctx = TransportContextHolder.getTransportContext();
        return (null != ctx) ? ((HttpServletConnection) ctx.getConnection()).getHttpServletRequest() : null;
    }
}
