/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.service.integrations.minlog;

import dk.sdsd.nsp.slalog.api.SLALogItem;
import dk.sundhedsdatastyrelsen.livstestamente.service.domain.OrganizationTypeVO;
import dk.sundhedsdatastyrelsen.livstestamente.service.domain.RequestContextVO;
import dk.sundhedsdatastyrelsen.livstestamente.service.util.Properties;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringRunner;

import static org.mockito.Mockito.mock;

@RunWith(SpringRunner.class)
@SpringBootTest
public class MinLogHoleThroughTest {

    // Warning: Creates data in the test environment for every test run. See minlogclient.properties to know where.

    @Autowired
    private Properties properties;

    @Autowired
    private MinLogDataWrapper minLogDataWrapper;

    @Test
    public void testActualLoggingToMinLogServiceLTR() throws Exception {
        RequestContextVO requestContextMock = new RequestContextVO();
        requestContextMock.setSlaLogItem(mock(SLALogItem.class));

        minLogDataWrapper.logReadActivity(
                requestContextMock,
                properties.getMinLogReadActivityTextLTR(),
                "0501792275",
                "12345678901234567890",
                "Regionshospital Randers, Akutcenter",
                OrganizationTypeVO.SKS,
                "0501792275",
                "2512489996",
                "LTR integration test"
        );
    }

    @Test
    public void testActualLoggingToMinLogServiceBTR() throws Exception {
        RequestContextVO requestContextMock = new RequestContextVO();
        requestContextMock.setSlaLogItem(mock(SLALogItem.class));

        minLogDataWrapper.logReadActivity(
                requestContextMock,
                properties.getMinLogReadActivityTextBTR(),
                "0501792275",
                "12345678901234567890",
                "Regionshospital Randers, Akutcenter",
                OrganizationTypeVO.SKS,
                "0501792275",
                "2512489996",
                "BTR integration test"
        );
    }

}
