/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.service.webservice.proxydata;

import dk.sds.dgws_idws_proxy.security.ProxyData;
import dk.sds.dgws_idws_proxy.security.RequestType;
import dk.sundhedsdatastyrelsen.livstestamente.service.domain.UserType;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnit;
import org.mockito.junit.MockitoRule;
import org.mockito.quality.Strictness;

import javax.servlet.http.HttpServletRequest;

import static org.junit.Assert.assertEquals;

public class ProxyMetaDataTests {

    private static final String personIdentifier = "1234567890";

    @Rule
    public MockitoRule rule = MockitoJUnit.rule().strictness(Strictness.STRICT_STUBS);

    @Mock
    private ProxyDataProvider proxyDataProvider;

    @Mock
    private HttpServletRequest httpServletRequest;

    private ProxyMetaData classUnderTest;

    @Before
    public void setUp() {
        classUnderTest = new ProxyMetaData(proxyDataProvider, httpServletRequest);
    }

    @Test
    public void findUserType_HealthCareProfessional() {
        // Arrange
        ProxyData proxyData = new ProxyData(RequestType.DGWS);
        proxyData.setAuthenticationLevel(String.valueOf(ProxyMetaData.LEVEL_MOCES));
        final boolean isAdmin = false;
        // Act
        final UserType userType = classUnderTest.findUserType(proxyData, personIdentifier, isAdmin);

        // Assert
        assertEquals(UserType.HealthCareProfessional, userType);
    }

    @Test
    public void findUserType_SystemUser() {
        // Arrange
        ProxyData proxyData = new ProxyData(RequestType.DGWS);
        proxyData.setAuthenticationLevel(String.valueOf(ProxyMetaData.LEVEL_FOCES));
        final boolean isAdmin = false;
        // Act
        final UserType userType = classUnderTest.findUserType(proxyData, personIdentifier, isAdmin);

        // Assert
        assertEquals(UserType.SystemUser, userType);
    }

    @Test
    public void findUserType_DataOwner() {
        // Arrange
        ProxyData proxyData = new ProxyData(RequestType.IDWS);
        proxyData.setCprnr(personIdentifier);
        final boolean isAdmin = false;
        // Act
        final UserType userType = classUnderTest.findUserType(proxyData, personIdentifier, isAdmin);

        // Assert
        assertEquals(UserType.DataOwner, userType);
    }

    @Test
    public void findUserType_Other() {
        // Arrange
        ProxyData proxyData = new ProxyData(RequestType.IDWS);
        proxyData.setCprnr("123"); // cpr not matching
        final boolean isAdmin = false;
        // Act
        final UserType userType = classUnderTest.findUserType(proxyData, personIdentifier, isAdmin);

        // Assert
        assertEquals(UserType.Other, userType);
    }
}
