/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.datacreator;

import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;

import java.time.Instant;

@Component
@ConfigurationProperties(prefix = "data-creator-properties", ignoreUnknownFields = false)
public class DataCreatorProperties {

    private String personFileName;

    private DataCreationProperties ltr = new DataCreationProperties();
    private DataCreationProperties btr = new DataCreationProperties();

    public String getPersonFileName() {
        return personFileName;
    }

    public void setPersonFileName(String personFileName) {
        this.personFileName = personFileName;
    }

    public DataCreationProperties getLtr() {
        return ltr;
    }

    public void setLtr(DataCreationProperties ltr) {
        this.ltr = ltr;
    }

    public DataCreationProperties getBtr() {
        return btr;
    }

    public void setBtr(DataCreationProperties btr) {
        this.btr = btr;
    }

    @Override
    public String toString() {
        return "DataCreatorProperties{" +
                "personFileName='" + personFileName + '\'' +
                ", ltr=" + ltr +
                ", btr=" + btr +
                '}';
    }

    public static class DataCreationProperties {
        private Instant dataTimeIntervalStart;
        private Instant dataTimeIntervalEnd;

        private int chanceOfUpdates;

        public Instant getDataTimeIntervalStart() {
            return dataTimeIntervalStart;
        }

        public void setDataTimeIntervalStart(Instant dataTimeIntervalStart) {
            this.dataTimeIntervalStart = dataTimeIntervalStart;
        }

        public Instant getDataTimeIntervalEnd() {
            return dataTimeIntervalEnd;
        }

        public void setDataTimeIntervalEnd(Instant dataTimeIntervalEnd) {
            this.dataTimeIntervalEnd = dataTimeIntervalEnd;
        }

        public int getChanceOfUpdates() {
            return chanceOfUpdates;
        }

        public void setChanceOfUpdates(int chanceOfUpdates) {
            this.chanceOfUpdates = chanceOfUpdates;
        }

        @Override
        public String toString() {
            return "DataCreationProperties{" +
                    "dataTimeIntervalStart=" + dataTimeIntervalStart +
                    ", dataTimeIntervalEnd=" + dataTimeIntervalEnd +
                    ", chanceOfUpdates=" + chanceOfUpdates +
                    '}';
        }
    }
}
