/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.migration;

import dk.sundhedsdatastyrelsen.livstestamente.migration.business.LivingWillMigration;
import dk.sundhedsdatastyrelsen.livstestamente.service.util.ServiceException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import java.time.Instant;

@Controller
public class MigrationController {

    private final LivingWillMigration livingWillMigration;

    private String cr = System.getProperty("line.separator");
    private Instant migrationStartTime = null;

    @Autowired
    public MigrationController(LivingWillMigration livingWillMigration) {
        this.livingWillMigration = livingWillMigration;
    }

    @GetMapping(value = "/status", produces = "text/plain")
    @ResponseBody
    public ResponseEntity<String> status() {
        StringBuilder b = new StringBuilder();
        b.append("Display time: ").append(Instant.now()).append(cr);
        b.append("Migration start time: ").append(migrationStartTime).append(cr);
        b.append("Is running: ").append(livingWillMigration.isRunning()).append(cr);
        b.append("Number of rows inserted in database: ").append(livingWillMigration.getNumberOfRowsInserted()).append(cr);
        b.append("Error count: ").append(livingWillMigration.getErrorCount()).append(cr);
        return new ResponseEntity<>(b.toString(), HttpStatus.OK);
    }

    @PutMapping(value = "/start", produces = "text/plain")
    @ResponseBody
    public ResponseEntity<String> start() {
        StringBuilder b = new StringBuilder();

        try {
            b.append("Started migration").append(cr);
            migrationStartTime = Instant.now();
            livingWillMigration.startMigration();
        } catch (ServiceException e) {
            b.append("Could not start: ").append(e.toString()).append(cr);
        }

        return new ResponseEntity<>(b.toString(), HttpStatus.OK);
    }

    @PutMapping(value = "/stop", produces = "text/plain")
    @ResponseBody
    public ResponseEntity<String> stop() {
        StringBuilder b = new StringBuilder();

        try {
            livingWillMigration.stopMigration();
            b.append("Stopped migration").append(cr);
        } catch (ServiceException e) {
            b.append("Could not start: ").append(e.toString()).append(cr);
        }

        return new ResponseEntity<>(b.toString(), HttpStatus.OK);
    }

}
