/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.migration.business;

import dk.sundhedsdatastyrelsen.livstestamente.migration.task.MigrationTask;
import dk.sundhedsdatastyrelsen.livstestamente.service.util.FaultCode;
import dk.sundhedsdatastyrelsen.livstestamente.service.util.FaultUtil;
import dk.sundhedsdatastyrelsen.livstestamente.service.util.ServiceException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.stereotype.Service;

import java.util.concurrent.Future;

@Service
public class LivingWillMigrationImpl implements LivingWillMigration {
    private final ThreadPoolTaskExecutor taskExecutor;
    private final MigrationTask migrationTask;

    private Future<Boolean> migrationTaskFuture = null;

    @Autowired
    public LivingWillMigrationImpl(ThreadPoolTaskExecutor taskExecutor, MigrationTask migrationTask) {
        this.migrationTask = migrationTask;
        this.taskExecutor = taskExecutor;
    }

    @Override
    public boolean isRunning() {
        return migrationTaskFuture != null && !migrationTaskFuture.isDone();
    }

    @Override
    public void startMigration() throws ServiceException {
        if (isRunning()) {
            FaultUtil.throwFault(FaultCode.GENERAL_ERROR, "Migration already running");
        }
        migrationTaskFuture = taskExecutor.submit(migrationTask);
    }

    @Override
    public void stopMigration() throws ServiceException {
        if (!isRunning()) {
            FaultUtil.throwFault(FaultCode.GENERAL_ERROR, "Migration is not running");
        }
        migrationTaskFuture.cancel(true);
    }

    @Override
    public int getErrorCount() {
        return migrationTask.getErrorCount();
    }

    @Override
    public int getNumberOfRowsInserted() {
        return migrationTask.getNumberOfRowsInserted();
    }

}
