/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.migration.dao;

import dk.sundhedsdatastyrelsen.livstestamente.service.dao.impl.LivingWillDAOImpl;
import dk.sundhedsdatastyrelsen.livstestamente.service.domain.LivingWillVO;
import dk.sundhedsdatastyrelsen.livstestamente.service.exception.DAOException;
import org.springframework.dao.DataAccessException;
import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.stereotype.Repository;

import javax.sql.DataSource;
import java.sql.Types;
import java.time.temporal.ChronoUnit;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@SuppressWarnings("SqlResolve")
@Repository
public class LivingWillMigrationDAOImpl extends LivingWillDAOImpl implements LivingWillMigrationDAO {

    public LivingWillMigrationDAOImpl(DataSource livingWillDataSource) {
        super(livingWillDataSource);
    }

    @Override
    public void createLivingWills(List<LivingWillVO> livingWillVOList) throws DAOException {
        final String sql = "INSERT INTO LivingWill " +
                "(Version, ValidFrom, ValidTo, ModifiedDateTime, PersonIdentifier, NoLifeProlongingIfDying, NoLifeProlongingIfSeverelyDegraded) " +
                "VALUES (:Version, :ValidFrom, :ValidTo, :ModifiedDateTime, :PersonIdentifier, :NoLifeProlongingIfDying, :NoLifeProlongingIfSeverelyDegraded)";

        try {
            List<Map<String, Object>> batchValues = new ArrayList<>(livingWillVOList.size());
            for (LivingWillVO livingWillVO : livingWillVOList) {
                batchValues.add(
                        new MapSqlParameterSource()
                                .addValue("Version", livingWillVO.getVersion(), Types.INTEGER)
                                .addValue("ValidFrom", java.sql.Timestamp.from(livingWillVO.getValidFrom().truncatedTo(ChronoUnit.SECONDS)), Types.TIMESTAMP)
                                .addValue("ValidTo", java.sql.Timestamp.from(livingWillVO.getValidTo().truncatedTo(ChronoUnit.SECONDS)), Types.TIMESTAMP)
                                .addValue("ModifiedDateTime", java.sql.Timestamp.from(livingWillVO.getModifiedDateTime().truncatedTo(ChronoUnit.SECONDS)), Types.TIMESTAMP)
                                .addValue("PersonIdentifier", livingWillVO.getPersonIdentifier(), Types.VARCHAR)
                                .addValue("NoLifeProlongingIfDying", livingWillVO.isNoLifeProlongingIfDying(), Types.TINYINT)
                                .addValue("NoLifeProlongingIfSeverelyDegraded", livingWillVO.isNoLifeProlongingIfSeverelyDegraded(), Types.TINYINT)
                                .getValues());
            }
            //noinspection unchecked
            namedParamJdbcTemplate.batchUpdate(sql, batchValues.toArray(new Map[livingWillVOList.size()]));
        } catch (DataAccessException e) {
            throw new DAOException("An error occurred inserting LivingWills", e);
        }
    }
}
