/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.migration.task;

import dk.sundhedsdatastyrelsen.livstestamente.migration.business.MigrationTaskHandler;
import dk.sundhedsdatastyrelsen.livstestamente.service.exception.DAOException;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.concurrent.Callable;
/**
 * Singleton (as default) component for managing thread
 */
@Component
public class MigrationTask implements Callable<Boolean> {

    private static final Logger logger = LogManager.getLogger(MigrationTask.class);

    private final MigrationTaskHandler migrationTaskHandler;

    @Autowired
    public MigrationTask(MigrationTaskHandler migrationHandler) {
        this.migrationTaskHandler = migrationHandler;
    }

    public int getErrorCount() {
        return migrationTaskHandler.getErrorCount();
    }

    public int getNumberOfRowsInserted() {
        return migrationTaskHandler.getNumberOfRowsInserted();
    }

    @Override
    public Boolean call() {
        try {
            logger.info("Migration started");
            //Migration in progress
            migrationTaskHandler.runMigration();
            // Now we are finished
            Thread.sleep(1);
            logger.info("Migration successfully completed");
        } catch (IOException e) {
            logger.fatal("Error reading datafiles for migration " + e);
        } catch (DAOException e) {
            logger.fatal("Database error: " + e + " " + e.getCause().toString());
        } catch (InterruptedException e) {
            logger.warn("Migration has been stopped");
        } catch (Exception e) {
            logger.fatal("Something went wrong", e);
        }

        return true;
    }
}
