/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.migration.dao;

import dk.sundhedsdatastyrelsen.livstestamente.service.domain.LivingWillVO;
import dk.sundhedsdatastyrelsen.livstestamente.service.exception.DAOException;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.transaction.annotation.Transactional;

import java.time.Instant;
import java.time.temporal.ChronoUnit;
import java.util.ArrayList;
import java.util.List;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

@RunWith(SpringRunner.class)
@SpringBootTest
@Transactional
public class LivingWillMigrationDAOImplTest {

    @Autowired
    private LivingWillMigrationDAOImpl dao;

    @Test
    public void createAndGetLivingWill_CreatesCorrectData() throws DAOException {
        // Arrange
        final Instant now = Instant.now().truncatedTo(ChronoUnit.SECONDS);

        List<LivingWillVO> livingWills = new ArrayList<>();
        livingWills.add(buildTestLivingWill("1111111111", now));
        livingWills.add(buildTestLivingWill("2222222222", now));

        // Act
        dao.createLivingWills(livingWills);

        // Assert
        LivingWillVO result0 = dao.getCurrentLivingWill(livingWills.get(0).getPersonIdentifier(), now);
        LivingWillVO result1 = dao.getCurrentLivingWill(livingWills.get(1).getPersonIdentifier(), now);

        assertLivingWill(livingWills.get(0), result0);
        assertLivingWill(livingWills.get(1), result1);
    }

    private void assertLivingWill(LivingWillVO expected, LivingWillVO actual) {
        assertNotNull(actual);
        assertEquals(expected.getPersonIdentifier(), actual.getPersonIdentifier());
        assertEquals(expected.getModifiedDateTime(), actual.getModifiedDateTime());
        assertEquals(expected.getValidFrom(), actual.getValidFrom());
        assertEquals(expected.getValidTo(), actual.getValidTo());
        assertEquals(expected.getVersion(), actual.getVersion());
    }

    private static LivingWillVO buildTestLivingWill(String personIdentifier, Instant now) {
        LivingWillVO livingWillVO = new LivingWillVO();
        livingWillVO.setVersion(456);
        livingWillVO.setValidFrom(now);
        livingWillVO.setValidTo(now.plusSeconds(5));
        livingWillVO.setModifiedDateTime(now);
        livingWillVO.setPersonIdentifier(personIdentifier);
        livingWillVO.setNoLifeProlongingIfDying(true);
        livingWillVO.setNoLifeProlongingIfSeverelyDegraded(false);
        return livingWillVO;
    }
}
